#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = __importDefault(require("commander"));
const commit_1 = require("../lib/scripts/commit");
const eslint_1 = require("../lib/scripts/eslint");
const jest_1 = require("../lib/scripts/jest");
const list_1 = require("../lib/scripts/list");
const release_1 = require("../lib/scripts/release");
const travis_1 = require("../lib/scripts/travis");
const vscode_1 = require("../lib/scripts/vscode");
const clock_1 = require("../lib/scripts/clock");
const sentry_1 = require("../lib/scripts/sentry");
const jenkins_1 = require("../lib/scripts/jenkins");
const selects_1 = require("../lib/selects");
const utils_1 = require("../lib/utils");
const prompts = require("prompts");
const program = commander_1.default.program;
function start() {
    return __awaiter(this, void 0, void 0, function* () {
        program
            .option("-D, --dep [dep...]", "需要集成的工具，支持 xiaoz cli -D jest eslint ts editorConfig commit vscode release travis clock sentry jenkins")
            .option("-a, --all", "是否全部集成")
            .option("-l, --list", "查看支持的工具")
            .parse(process.argv);
        let { dep } = program.opts();
        const { all, list } = program.opts();
        if (dep === undefined && !all && !list) {
            const { value } = yield prompts(selects_1.selectListOption);
            dep = Array.isArray(value) ? value : value ? [value] : [];
            if (!(dep === null || dep === void 0 ? void 0 : dep.length)) {
                throw new Error(`必须选择dep`);
            }
        }
        dep = dep || [];
        const hasEditorConfig = dep.includes(selects_1.ChoiceEnum.editorConfig);
        if (hasEditorConfig || all) {
            (0, utils_1.logFn)(() => (0, eslint_1.addEditorConfig)(), `editorConfig`);
        }
        const hasTs = dep.includes(selects_1.ChoiceEnum.ts);
        if (hasTs || all) {
            (0, utils_1.logFn)(() => (0, eslint_1.addTs)(), `ts`);
        }
        const hasEslint = dep.includes(selects_1.ChoiceEnum.eslint);
        if (hasEslint || all) {
            (0, utils_1.logFn)(() => (0, eslint_1.addEslint)(hasEditorConfig), `eslint`);
        }
        const hasVscode = dep.includes(selects_1.ChoiceEnum.vscode);
        if (hasVscode || all) {
            (0, utils_1.logFn)(() => (0, vscode_1.addVscode)(), `vscode`);
        }
        const hasCommit = dep.includes(selects_1.ChoiceEnum.commit);
        if (hasCommit || all) {
            (0, utils_1.logFn)(() => (0, commit_1.addCommit)(), `commit`);
        }
        const hasRelease = dep.includes(selects_1.ChoiceEnum.release);
        if (hasRelease || all) {
            (0, utils_1.logFn)(() => (0, release_1.addRelease)(), `release`);
        }
        const hasJest = dep.includes(selects_1.ChoiceEnum.jest);
        if (hasJest || all) {
            (0, utils_1.logFn)(() => (0, jest_1.addJest)(), `jest`);
        }
        const hasTravis = dep.includes(selects_1.ChoiceEnum.travis);
        if (hasTravis || all) {
            (0, utils_1.logFn)(() => (0, travis_1.addTravis)(), `jest`);
        }
        if (list) {
            (0, list_1.showList)();
        }
        const hasSentry = dep.includes(selects_1.ChoiceEnum.sentry);
        if (hasSentry || all) {
            (0, utils_1.logFn)(() => (0, sentry_1.addSentry)(), `sentry`);
        }
        const hasJenkins = dep.includes(selects_1.ChoiceEnum.jenkins);
        if (hasJenkins || all) {
            (0, utils_1.logFn)(() => (0, jenkins_1.addJenkins)(), `jenkins`);
        }
        const cellBack = () => {
            const hasClock = dep.includes(selects_1.ChoiceEnum.clock);
            if (hasClock || all) {
                (0, utils_1.logFn)(() => (0, clock_1.addClock)(), `clock`);
            }
            if (hasEslint || all) {
                setTimeout(() => {
                    (() => __awaiter(this, void 0, void 0, function* () {
                        const response = yield prompts({
                            type: "text",
                            name: "meaning",
                            message: "是否立即执行eslint(y/n)",
                        });
                        if (response.meaning === "y" || response.meaning === "Y") {
                            (0, utils_1.exec)("npm run eslint");
                        }
                    }))();
                }, 10);
            }
        };
        yield (0, utils_1.installDeps)(cellBack);
    });
}
start();
